@@ -2,23 +2,25 @@ package PPI;
 
 # See POD at end for documentation
 
-use 5.005;
+use 5.006;
 use strict;
 
 # Set the version for CPAN
 use vars qw{$VERSION $XS_COMPATIBLE @XS_EXCLUDE};
 BEGIN {
-	$VERSION       = '1.115';
+	$VERSION       = '1.203';
 	$XS_COMPATIBLE = '0.845';
 	@XS_EXCLUDE    = ();
 }
 
 # Load everything
+use PPI::Exception            ();
 use PPI::Element              ();
 use PPI::Token                ();
 use PPI::Statement            ();
 use PPI::Structure            ();
 use PPI::Document             ();
+use PPI::Document::File       ();
 use PPI::Document::Normalized ();
 use PPI::Normal               ();
 use PPI::Tokenizer            ();
@@ -170,7 +172,10 @@ the SourceForge project that publishes PPI and a large collection of other
 applications and modules related to the (document) parsing of Perl source
 code.
 
-You can find this project at L<http://sf.net/projects/parseperl>.
+You can find this project at L<http://sf.net/projects/parseperl>,
+however we no longer use the SourceForge CVS server.  Instead, the
+current development version of PPI is available via SVN at
+L<http://svn.ali.as/cpan/trunk/PPI/>.
 
 =head2 Why Parse Perl?
 
@@ -208,7 +213,7 @@ or whatever. All the sort of things you'd want from a L<Perl::Editor>.
 =item Layout
 
 Change the layout of code without changing its meaning. This includes
-techniques such as tidying (like L<perltidy>), obfuscation, compressiong and
+techniques such as tidying (like L<perltidy>), obfuscation, compressing and
 "squishing", or to implement formatting preferences or policies.
 
 =item Presentation
@@ -283,7 +288,7 @@ will serialize back out to the same string of code that was read in,
 repairing the parser's mistake as it heads back out to the file.
 
 The end result is that if you parse in a file and serialize it back out
-without changing the tree, you are guarenteed to get the same file you
+without changing the tree, you are guaranteed to get the same file you
 started with. PPI does this correctly and reliably for 100% of all known
 cases.
 
@@ -291,7 +296,7 @@ B<What goes in, will come out. Every time.>
 
 The one minor exception at this time is that if the newlines for your file
 are wrong (meaning not matching the platform newline format), PPI will
-localisation of them for you. (It isn't to be convenient, supporting
+localise them for you. (It isn't to be convenient, supporting
 arbitrary newlines would make some of the code more complicated)
 
 Better control of the newline type is on the wish list though, and
@@ -332,7 +337,7 @@ codebase. Speaking of which...
 
 The Tokenizer takes source code and converts it into a series of tokens. It
 does this using a slow but thorough character by character manual process,
-rather than using a pattern system or complex regexs.
+rather than using a pattern system or complex regexes.
 
 Or at least it does so conceptually. If you were to actually trace the code
 you would find it's not truly character by character due to a number of
@@ -381,7 +386,7 @@ syntax.
 
 =head2 The PDOM Class Tree
 
-The following lists all of the 62 current PDOM classes, listing with indentation
+The following lists all of the 67 current PDOM classes, listing with indentation
 based on inheritance.
 
    PPI::Element
@@ -415,6 +420,12 @@ based on inheritance.
          PPI::Token::Comment
          PPI::Token::Pod
          PPI::Token::Number
+            PPI::Token::Number::Binary
+            PPI::Token::Number::Octal
+            PPI::Token::Number::Hex
+            PPI::Token::Number::Float
+               PPI::Token::Number::Exp
+            PPI::Token::Number::Version
          PPI::Token::Word
          PPI::Token::DashedWord
          PPI::Token::Symbol
@@ -463,46 +474,54 @@ At the top of all complete PDOM trees is a L<PPI::Document> object. It
 represents a complete file of Perl source code as you might find it on
 disk.
 
+There are some specialised types of document, such as L<PPI::Document::File>
+and L<PPI::Document::Normalized> but for the purposes of the PDOM they are
+all just considered to be the same thing.
+
 Each Document will contain a number of B<Statements>, B<Structures> and
 B<Tokens>.
 
 A L<PPI::Statement> is any series of Tokens and Structures that are treated
 as a single contiguous statement by perl itself. You should note that a
 Statement is as close as PPI can get to "parsing" the code in the sense that
-perl-itself parses Perl code when it is building the op-tree. Because of the
-assumed isolation, PPI cannot accurately determine precedence of operators
-or which tokens are implicit arguments to a sub call.
+perl-itself parses Perl code when it is building the op-tree.
 
-So rather than lead you on with a bad guess, PPI does not attempt to
-determine precedence or sub paramaters at all.
+Because of the isolation and Perl's syntax, it is provably impossible for
+PPI to accurately determine precedence of operators or which tokens are
+implicit arguments to a sub call.
 
-At a fundamental level, it only knows that this series of elements represents
-a single Statement as perl sees it, and does so with reasonable certainty.
+So rather than lead you on with a bad guess that has a strong chance of
+being wrong, PPI does not attempt to determine precedence or sub parameters
+at all.
 
-However for specific Statement types the PDOM is able to derive additional
-useful information about their meaning. For the best and most heavily used
-example, see L<PPI::Statement::Include>.
+At a fundamental level, it only knows that this series of elements
+represents a single Statement as perl sees it, but it can do so with
+enough certainty that it can be trusted.
+
+However, for specific Statement types the PDOM is able to derive additional
+useful information about their meaning. For the best, most useful, and most
+heavily used example, see L<PPI::Statement::Include>.
 
 A L<PPI::Structure> is any series of tokens contained within matching braces.
 This includes code blocks, conditions, function argument braces, anonymous
-array constructors, lists, scoping braces and all other syntactic structures
-represented by a matching pair of braces, including C<E<lt>READLINEE<gt>>
-braces.
+array and hash constructors, lists, scoping braces and all other syntactic
+structures represented by a matching pair of braces, including (although it
+may not seem obvious at first) C<E<lt>READLINEE<gt>> braces.
 
 Each Structure contains none, one, or many Tokens and Structures (the rules
 for which vary for the different Structure subclasses)
 
-In the PDOM structure rules, a Statement can B<never> directly contain another
-child Statement, a Structure can B<never> directly contain another child
-Structure, and a Document can B<never> contain another Document anywhere in
-the tree.
+Under the PDOM structure rules, a Statement can B<never> directly contain
+another child Statement, a Structure can B<never> directly contain another
+child Structure, and a Document can B<never> contain another Document
+anywhere in the tree.
 
 Aside from these three rules, the PDOM tree is extremely flexible.
 
 =head2 The PDOM at Work
 
 To demonstrate the PDOM in use lets start with an example showing how the
-PDOM tree might look for the following chunk of simple Perl code.
+tree might look for the following chunk of simple Perl code.
 
   #!/usr/bin/perl
 
@@ -510,12 +529,13 @@ PDOM tree might look for the following chunk of simple Perl code.
 
   exit();
 
-Translated into a PDOM tree it would have the following structure.
+Translated into a PDOM tree it would have the following structure (as shown
+via the included L<PPI::Dumper>).
 
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
     PPI::Token::Whitespace             '\n'
-    PPI::Statement
+    PPI::Statement::Expression
       PPI::Token::Bareword             'print'
       PPI::Structure::List             ( ... )
         PPI::Token::Whitespace         ' '
@@ -525,7 +545,7 @@ Translated into a PDOM tree it would have the following structure.
       PPI::Token::Structure            ';'
     PPI::Token::Whitespace             '\n'
     PPI::Token::Whitespace             '\n'
-    PPI::Statement
+    PPI::Statement::Expression
       PPI::Token::Bareword             'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
@@ -542,13 +562,13 @@ whitespace. Here it is again, sans the distracting whitespace tokens.
 
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
-    PPI::Statement
+    PPI::Statement::Expression
       PPI::Token::Bareword             'print'
       PPI::Structure::List             ( ... )
         PPI::Statement::Expression
           PPI::Token::Quote::Double    '"Hello World!"'
       PPI::Token::Structure            ';'
-    PPI::Statement
+    PPI::Statement::Expression
       PPI::Token::Bareword             'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
@@ -576,16 +596,19 @@ The Document object, the root of the PDOM.
 =item L<PPI::Document::Fragment>
 
 A cohesive fragment of a larger Document. Although not of any real current
-use, it is planned for use in certain internal tree manipulation
-algortihms.
+use, it is needed for use in certain internal tree manipulation
+algorithms.
 
 For example, doing things like cut/copy/paste etc. Very similar to a
 L<PPI::Document>, but has some additional methods and does not represent
 a lexical scope boundary.
 
+A document fragment is also non-serializable, and so cannot be written out
+to a file.
+
 =item L<PPI::Dumper>
 
-A simple class for dumping readable debugging version of PDOM structures,
+A simple class for dumping readable debugging versions of PDOM structures,
 such as in the demonstration above.
 
 =item L<PPI::Element>
@@ -650,7 +673,7 @@ treads carefully when working with it.
 
 Most of the complication is the result of optimizations which have tripled
 the tokenization speed, at the expense of maintainability. We cope with the
-spagetti by heavily commenting everything.
+spaghetti by heavily commenting everything.
 
 =item L<PPI::Transform>
 
@@ -693,43 +716,54 @@ C<Parse::Perl> project itself.
 
 =head1 TO DO
 
-- Many more analysis and utility methods for PDOM classes (post 1.000)
+- Many more analysis and utility methods for PDOM classes
 
-- Creation of a PPI::Tutorial document (post 1.000)
+- Creation of a PPI::Tutorial document
 
-- We can _always_ write more and better unit tests
+- Add many more key functions to PPI::XS
 
-- Add better support for tabs (1.100)
+- We can B<always> write more and better unit tests
 
-- Add better handling of non-local newlines (due 1.100)
+- Complete the full implementation of -E<gt>literal (1.200)
 
-- Full understanding of scoping (due 1.100)
-
-- Add many more key functions to PPI::XS (post 1.000)
+- Full understanding of scoping (due 1.300)
 
 =head1 SUPPORT
 
-Bugs should be always be reported vi the following URI
+This module is stored in an Open Repository at the following address.
+
+L<http://svn.ali.as/cpan/trunk/PPI>
+
+Write access to the repository is made available automatically to any
+published CPAN author, and to most other volunteers on request.
+
+If you are able to submit your bug report in the form of new (failing)
+unit tests, or can apply your fix directly instead of submitting a patch,
+you are B<strongly> encouraged to do so, as the author currently maintains
+over 100 modules and it can take some time to deal with non-"Critical" bug
+reports or patches.
+
+This will also guarentee that your issue will be addressed in the next
+release of the module.
+
+For large changes though, please consider creating a branch so that they
+can be properly reviewed and trialed before being applied to the trunk.
+
+If you cannot provide a direct test or fix, or don't have time to do so,
+then regular bug reports are still accepted and appreciated via the CPAN
+bug tracker.
 
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PPI>
 
-When reporting bugs, you are B<highly> recommended to include test
-cases if at all possible, as the odds are by the time you are
-submitting a bug you understand what should actually happen better
-than the authors.
-
-Test fragments are fine, or in larger cases simply copy/paste one of
-the other small test scripts and replace the contents with your own
-tests.
-
 For other issues or questions, contact the C<Parse::Perl> project mailing
 list.
 
-For commercial or media issues, contact the author.
+For commercial or media-related enquiries, or to have your SVN commit bit
+enabled, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy <cpan@ali.as>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 ACKNOWLEDGMENTS
 
@@ -741,10 +775,18 @@ Another big thank you to The Perl Foundation
 (L<http://www.perlfoundation.org/>) for funding for the final big
 refactoring and completion run.
 
-Most of all, thanks to those brave soles willing to dive in and use,
-test drive and provide feedback on PPI, in a few cases before it was
-tamed and ready, and still did extremely distasteful things to you like
-eating 50 meg of RAM a second.
+Also, to the various co-maintainers that have contributed both large and
+small with tests and patches and especially to those rare few who have
+deep-dived into the guts to (gasp) add a feature.
+
+  - Dan Brook       : PPIx::XPath, Acme::PerlML
+  - Audrey Tang     : "Line Noise" Testing
+  - Arjen Laarhoven : Three-element ->location support
+
+And finally, thanks to those brave ( and foolish :) ) soles willing to dive
+in and use, test drive and provide feedback on PPI before version 1.000,
+in some cases before it made it to beta quality, and still did extremely
+distasteful things (like eating 50 meg of RAM a second).
 
 I owe you all a beer. Corner me somewhere and collect at your convenience.
 If I missed someone who wasn't in my email history, thank you too :)
@@ -775,16 +817,18 @@ If I missed someone who wasn't in my email history, thank you too :)
   - Johnny Lee
   - Johan Lindstrom
 
-And to single one person out, Randal Schwartz who (mostly) patiently
+And to single one person out, thanks go to Randal Schwartz who
 spent a great number of hours in IRC over a critical 6 month period
-"aggresively explaining" why Perl is impossibly unparsable and
-shoving evil and ugly corner cases in my face. He remains a tireless
-devil's advocate and without his continued support this project
-genuinely could never have been completed. He has my deepest thanks.
+explaining why Perl is impossibly unparsable and constantly shoving evil
+and ugly corner cases in my face. He remained a tireless devil's advocate,
+and without his support this project genuinely could never have been
+completed.
+
+So for my schooling in the Deep Magiks, you have my deepest gratitude Randal.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
