@@ -24,9 +24,9 @@ PPI::Statement::Null - A useless null statement
 =head1 DESCRIPTION
 
 C<PPI::Statement::Null> is a utility class designed to handle situations
-where PPI encounters a naked statement seperator.
+where PPI encounters a naked statement separator.
 
-Although strictly speaking, the semicolon is a statement B<seperator>
+Although strictly speaking, the semicolon is a statement B<separator>
 and not a statement B<terminator>, PPI considers a semicolon to be a
 statement terminator under most circumstances.
 
@@ -45,7 +45,7 @@ use base 'PPI::Statement';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.203';
 }
 
 # A null statement is not significant
@@ -57,15 +57,15 @@ sub significant { '' }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
